@@ -24,7 +24,7 @@ class LogLevel(Enum):
     DEBUG: str = "DEBUG"
 
 
-class PyGcronException(Exception):
+class PyGocronException(Exception):
     pass
 
 
@@ -73,10 +73,10 @@ class PyGoCron:
             if data["message"] == "操作成功":
                 self._headers = {"Auth-Token": data["data"]["token"]}
             else:
-                raise PyGcronException(f"Authentication Error, details: {str(data)}")
+                raise PyGocronException(f"Authentication error, details: {response.text}")
         else:
-            raise PyGcronException(
-                f"Authentication Error, Status code: {response.status_code}"
+            raise PyGocronException(
+                f"Authentication error, details: {response.text}"
             )
 
     def create_task(
@@ -157,15 +157,15 @@ class PyGoCron:
         if response.status_code == 200:
             data = json.loads(response.text)
             if data["message"] == "保存成功":
-                logger_print(f"Task Created:`{name}` Successfully", LogLevel.SUCCESS)
+                logger_print(f"Task created:`{name}` successfully", LogLevel.SUCCESS)
                 return self.get_task_id_lagged(name=name)
             else:
-                raise PyGcronException(
-                    f"Create Task:`{name}` Error, Details: {response.text}"
+                raise PyGocronException(
+                    f"Create task:`{name}` rrror, details: {response.text}"
                 )
         else:
-            raise PyGcronException(
-                f"Create Task:`{name}` Error, Details: {response.text}"
+            raise PyGocronException(
+                f"Create task:`{name}` rrror, details: {response.text}"
             )
 
     def run_task(self, task_id) -> int:
@@ -180,9 +180,9 @@ class PyGoCron:
                 logger_print("Task Triggerd Successfully", LogLevel.SUCCESS)
                 return self.get_latest_run_id(task_id)
             else:
-                raise PyGcronException(f"Canot Trigger Task, Details: {response.text}")
+                raise PyGocronException(f"Canot trigger task, details: {response.text}")
         else:
-            raise PyGcronException(f"Canot Trigger Task, Details: {response.text}")
+            raise PyGocronException(f"Canot trigger task, details: {response.text}")
 
     def get_tasks(
         self,
@@ -230,11 +230,11 @@ class PyGoCron:
             if data["message"] == "操作成功":
                 return data["data"]
             else:
-                raise PyGcronException(
-                    f"Can not Fetch Task List, Details: {response.text}"
+                raise PyGocronException(
+                    f"Can not fetch task list, details: {response.text}"
                 )
         else:
-            raise PyGcronException(f"Can not Fetch Task List, Details: {response.text}")
+            raise PyGocronException(f"Can not fetch task list, details: {response.text}")
 
     def get_task_id_by_name(self, name: str):
         """
@@ -249,7 +249,7 @@ class PyGoCron:
             try:
                 task_id = data["data"][0]["id"]
             except IndexError:
-                raise PyGcronException(f"Task Name `{name}` Not Found")
+                raise PyGocronException(f"Task Name `{name}` Not Found")
             else:
                 return task_id
 
@@ -290,11 +290,11 @@ class PyGoCron:
             if data["message"] == "操作成功":
                 return data["data"]
             else:
-                raise PyGcronException(
-                    f"Can not Fetch Task Log, Details: {response.text}"
+                raise PyGocronException(
+                    f"Can not fetch task log, details: {response.text}"
                 )
         else:
-            raise PyGcronException(f"Can not Fetch Task Log, Details: {response.text}")
+            raise PyGocronException(f"Can not Fetch Task Log, Details: {response.text}")
 
     def check_run_status(self, task_id, run_id) -> RunStatus:  # 0 失败 1 在运行 2 成功
         """
@@ -323,27 +323,6 @@ class PyGoCron:
             logger_print("run id not found", LogLevel.WARN)
             return None
 
-    def get_nodes(self):
-        """
-        Get all nodes(server adddress info)
-        """
-        url = urljoin(self._base_url, "api/host/all")
-        response = requests.get(url, headers=self._headers)
-
-        if response.status_code == 200:
-            data = json.loads(response.text)
-
-            if data["message"] == "操作成功":
-                return data["data"]
-            else:
-                raise PyGcronException(
-                    f"Can not Fetch All Nodes(hosts), Details: {response.text}"
-                )
-        else:
-            raise PyGcronException(
-                f"Can not Fetch All Nodes(hosts), Details: {response.text}"
-            )
-
     def disable_task(self, task_id: int):
         """
         Disable a task by task id 
@@ -359,13 +338,13 @@ class PyGoCron:
         if response.status_code == 200:
             data = json.loads(response.text)
             if data["message"] == "操作成功":
-                logger_print("Task Disabled Successfully", LogLevel.SUCCESS)
+                logger_print("Task disabled successfully", LogLevel.SUCCESS)
             else:
-                raise PyGcronException(
-                    f"Can Not Disable Task, Details: {response.text}"
+                raise PyGocronException(
+                    f"Can not disable task, details: {response.text}"
                 )
         else:
-            raise PyGcronException(f"Can Not Disable Task, Details: {response.text}")
+            raise PyGocronException(f"Can not disable task, details: {response.text}")
 
     def enable_task(self, task_id: int):
         """
@@ -382,9 +361,9 @@ class PyGoCron:
             if data["message"] == "操作成功":
                 logger_print("Task Enabled Successfully", LogLevel.SUCCESS)
             else:
-                raise PyGcronException(f"Can Not Enable Task, Details: {response.text}")
+                raise PyGocronException(f"Can not enable task, details: {response.text}")
         else:
-            raise PyGcronException(f"Can Not Enable Task, Details: {response.text}")
+            raise PyGocronException(f"Can not enable task, details: {response.text}")
 
     def get_task_id_lagged(self, name, wait=1) ->  int:
         """
@@ -405,7 +384,7 @@ class PyGoCron:
         ----
         task_id: task id
         """
-        time.sleep(1)  # wait until the record be ready in database
+        time.sleep(wait)  # wait until the record be ready in database
         logs = self.get_task_logs(task_id=task_id,)
         logs_data = logs["data"]
         if logs_data:
@@ -449,12 +428,92 @@ class PyGoCron:
             if data["message"] == "操作成功":
                 logger_print("Task Deleted Successfully", LogLevel.SUCCESS)
             else:
-                raise PyGcronException(
-                    f"Can Not Delete the Task, Details: {response.text}"
+                raise PyGocronException(
+                    f"Can not delete the task, details: {response.text}"
                 )
         else:
-            raise PyGcronException(f"Can Not Delete the Task, Details: {response.text}")
+            raise PyGocronException(f"Can not delete the task, details: {response.text}")
 
+    def get_nodes(self):
+        """
+        Get all nodes(server adddress info)
+        """
+        url = urljoin(self._base_url, "api/host/all")
+        response = requests.get(url, headers=self._headers)
+
+        if response.status_code == 200:
+            data = json.loads(response.text)
+
+            if data["message"] == "操作成功":
+                return data["data"]
+            else:
+                raise PyGocronException(
+                    f"Can not fetch all nodes(hosts), details: {response.text}"
+                )
+        else:
+            raise PyGocronException(
+                f"Can not fetch all nodes(hosts), details: {response.text}"
+            )
+
+
+    def add_new_node(self, ip:str, port:int, alias:str, remark:str):
+        """
+        Add a new node to gocron. To make sure the node you added will work well, you need to check its accesibility by run `check_node` method 
+
+        Params
+        -----
+        ip: ip address for the node 
+        port: port
+        alias: alias for node
+        remark: comment or tag for the node
+        """
+        url = urljoin(
+            self._base_url, f"api/host/store"
+        )  
+        payload = {
+           "id":"",
+           "name": ip, 
+           "port": port,
+           "alias": alias,
+           "remark": remark,
+        }
+        headers = deepcopy(self._headers)
+        headers["Content-Type"] = "application/x-www-form-urlencoded"
+        response = requests.post(url, headers=headers, params=payload)  
+
+        print(response.request.url)
+        if response.status_code == 200:
+            data = json.loads(response.text)
+            if data["message"] == "保存成功":
+                logger_print("Node added successfully", LogLevel.SUCCESS)
+            else:
+                raise PyGocronException(
+                    f"Can not add node, details: {response.text}"
+                )
+        else:
+            raise PyGocronException(f"Can not add node, details: {response.text}")
+    
+    def check_node(self, node_id):
+        """
+        Check if a node is accessible or not
+        """
+        url = urljoin(
+            self._base_url, f"api/host/ping/{node_id}"
+        )  
+
+        response = requests.get(url, headers=self._headers)  
+
+        if response.status_code == 200:
+            data = json.loads(response.text)
+            if data["message"] == "连接成功":
+                logger_print("Node is running Successfully", LogLevel.SUCCESS)
+            else:
+                raise PyGocronException(
+                    f"Can not connect to node, details: {response.text}"
+                )
+        else:
+            raise PyGocronException(f"Can not connect to node, details: {response.text}")
+    
 
     def get_all_methods(self):
         all_methods = dir(self)
@@ -463,4 +522,5 @@ class PyGoCron:
             for method in all_methods
             if not method.startswith("_") and method != "get_all_methods"
         ]
-        print("\n".join(sorted(methods)))
\ No newline at end of file
+        print("\n".join(sorted(methods)))
+   
